Traceroute.Result.Error (traceroute v0.2.5)

Represents a hop that returned an error during traceroute.

This struct captures errors other than timeouts, such as network unreachable, host unreachable, or other ICMP error responses.

Summary

Functions

Creates a new Error result.

Types

t()

@type t() :: %Traceroute.Result.Error{reason: atom() | term(), ttl: pos_integer()}

Functions

new(ttl, reason)

@spec new(pos_integer(), atom() | term()) :: t()

Creates a new Error result.