Traceroute.Protocols.ICMP.DestinationUnreachable (traceroute v0.2.4)
View SourceRepresents an ICMP Destination Unreachable message (Type 3).
This message is returned when a packet cannot be delivered to its destination. In traceroute, a "Port Unreachable" (code 3) indicates the packet has reached the destination server but the target port is not open - which is the expected behavior signaling the end of the route.
See: https://en.wikipedia.org/wiki/Internet_Control_Message_Protocol#Destination_unreachable