Traceroute.Result.Timeout (traceroute v0.2.5)
View SourceRepresents a hop that did not respond within the timeout period.
When a router or destination doesn't respond to a probe packet, this result is recorded after all retries have been exhausted.
Summary
Functions
Creates a new Timeout result.
Types
@type t() :: %Traceroute.Result.Timeout{ retries: non_neg_integer(), ttl: pos_integer() }
Functions
@spec new(ttl :: pos_integer(), retries :: non_neg_integer()) :: t()
Creates a new Timeout result.